@@ -3,9 +3,7 @@
 import json
 import sys
 
-sys.path.append('../../../')
-
-from server_distrib.server.common.decorators import Log
+from common.decorators import Log
 
 
 @Log()
